@@ -10,8 +10,10 @@
 #'
 #' @param sibling If \code{TRUE}, then only \file{.Renviron.d/} and \file{.Rprofile.d/} directories with a sibling \file{.Renviron} and \file{.Rprofile} in the same location will be considered.
 #' @param all If \code{TRUE}, then \emph{all} \file{.Renviron.d/} and \file{.Rprofile.d/} directories found on \link[base:Startup]{the R startup search path} are processed, otherwise only the \emph{first ones} found.
+#' @param on_error Action taken when an error is detected when sourcing an Rprofile file.  It is not possible to detect error in Renviron files; they are always ignored with a message that cannot be captured.
 #' @param unload If \code{TRUE}, then the package is unloaded afterward, otherwise not.
 #' @param skip If \code{TRUE}, startup directories will be skipped.  If \code{NA}, they will be skipped if command-line options \code{--vanilla}, \code{--no-init-file}, and / or \code{--no-environ} were specified.
+#' @param dryrun If \code{TRUE}, everything is done except the processing of the startup files.
 #' @param debug If \code{TRUE}, debug messages are outputted, otherwise not.
 #'
 #' @section User-specific installation:
@@ -37,25 +39,25 @@
 #' startup::startup()
 #'
 #' # For finer control of on exactly what files are used
-#' # functions renviron() and rprofile() are also available:
+#' # functions renviron_d() and rprofile_d() are also available:
 #'
 #' # Initiate first .Renviron.d/ found on search path
-#' startup::renviron()
+#' startup::renviron_d()
 #'
 #' # Initiate all .Rprofile.d/ directories found on the startup search path
-#' startup::rprofile(all = TRUE)
+#' startup::rprofile_d(all = TRUE)
 #' }
 #'
-#' @describeIn startup \code{renviron()} followed by \code{rprofile()} and then the package is unloaded
+#' @describeIn startup \code{renviron_d()} followed by \code{rprofile_d()} and then the package is unloaded
 #' @export
-startup <- function(sibling = FALSE, all = FALSE, unload = TRUE, skip = NA, debug = NA) {
+startup <- function(sibling = FALSE, all = FALSE, on_error = c("error", "warning", "immediate.warning", "message", "ignore"), unload = TRUE, skip = NA, dryrun = NA, debug = NA) {
   debug(debug)
 
   # (i) Load custom .Renviron.d/* files
-  renviron(sibling = sibling, all = all, skip = skip)
+  renviron_d(sibling = sibling, all = all, skip = skip, dryrun = dryrun)
   
   # (ii) Load custom .Rprofile.d/* files
-  rprofile(sibling = sibling, all = all, skip = skip)
+  rprofile_d(sibling = sibling, all = all, skip = skip, dryrun = dryrun, on_error = on_error)
 
   res <- api()
   if (unload) unload()
